@@ -1,38 +1,39 @@
-from .dtypes import InputTypes, OutputTypes
 from .dtypes_encode_decode import *
 from .dtypes_extract_wrap import *
-
+from . import DTypes
+# import pdb
+# pdb.set_trace()
 decoders = {
-    InputTypes.STRING: identity, # can be an identity function if decoding not required. 
+    DTypes.STRING: identity, # can be an identity function if decoding not required. 
                                       # This is so that all decoding functions follow the same pattern.
                                       # The same code can be reused.
-    InputTypes.FLOAT_NDARRAY: dict_to_float_ndarray,
-    InputTypes.FLOAT: string_to_float # identify function if decoding not required
+    DTypes.FLOAT_NDARRAY: dict_to_float_ndarray,
+    DTypes.FLOAT: string_to_float # identify function if decoding not required
 }
 
 encoders = {
-    OutputTypes.STRING: identity, # can be an identity function if encoding not required. 
+    DTypes.STRING: identity, # can be an identity function if encoding not required. 
                                       # This is so that all encoding functions follow the same pattern.
                                       # The same code can be reused.
-    OutputTypes.FLOAT_NDARRAY: float_ndarray_to_dict,
-    OutputTypes.FLOAT: float_to_string # identify function if encoding not required
+    DTypes.FLOAT_NDARRAY: float_ndarray_to_dict,
+    DTypes.FLOAT: float_to_string # identify function if encoding not required
 }
 
 
 # extractors take Request object and return the input to the decoder
 extract_input = {
-    InputTypes.STRING: extract_data,
-    InputTypes.FLOAT_NDARRAY: extract_data,
-    InputTypes.FLOAT: extract_data # identify function if encoding not required
+    DTypes.STRING: extract_data,
+    DTypes.FLOAT_NDARRAY: extract_data,
+    DTypes.FLOAT: extract_data # identify function if encoding not required
 }
 
 # wrap output takes the encoded output and places it in the appropritate position in the response
 wrap_output = {
-    OutputTypes.STRING: wrap_data, # can be an identity function if encoding not required. 
+    DTypes.STRING: wrap_data, # can be an identity function if encoding not required. 
                                       # This is so that all encoding functions follow the same pattern.
                                       # The same code can be reused.
-    OutputTypes.FLOAT_NDARRAY: wrap_data,
-    OutputTypes.FLOAT: wrap_data # identify function if encoding not required
+    DTypes.FLOAT_NDARRAY: wrap_data,
+    DTypes.FLOAT: wrap_data # identify function if encoding not required
 }
 
 
